@@ -9,8 +9,10 @@ logger = logging.getLogger(__name__)
 # https://daskhub.dev.ctaodc.ch/services/downloadservice/fetch/pnfs/cta.cscs.ch/lst/DL1/20230226/v0.9_calib12100/tailcut84
 
 
-def fetch_and_save_file(url, fn):                
-    with open(fn, "w") as outf:
+def fetch_and_save_file(url, fn):
+    total_wrote = 0
+
+    with open(fn, "wb") as outf:
         with requests.get(
             urljoin("http://hub:5000/services/downloadservice/fetch/pnfs/cta.cscs.ch/", url),
             params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
@@ -19,5 +21,8 @@ def fetch_and_save_file(url, fn):
             f.raise_for_status()
             for r in f.iter_content(chunk_size=1024*1024):
                 outf.write(r)                
+                total_wrote += len(r)
+
+    return total_wrote
         
     
\ No newline at end of file
